#ifndef PRINT_ERROR_H
#define PRINT_ERROR_H

#include "struct_CPDD.h"

#include <stdio.h>
#include <string.h>

#include <errno.h>

static inline void print_error(const char *func, const char *file, const int line, CPDD *cpdd);

/*******************************************************************************
*******************************************************************************/
static inline void print_error(const char *func, const char *file, const int line, CPDD *cpdd)
{
	printf("%s : %d行\n", file, line);
	if(strcmp(func, "NODATA") != 0)
	{
		perror(func);
	}

	cpdd->total_error++;
}

#endif
